<?php
/**
 * Plugin Name: TweetView-Widget
 * Plugin URI: http://blog.ppfeufer.de/tweetview-widget-anzeige-der-letzten-tweets-in-der-wordpress-sidebar/
 * Description: Adds a widget to your blogs sidebar to show your latest tweets. (XHTML-valid - based on Tweetbox from Rob Carr)
 * Version: 1.3.6
 * Author: <a href="http://sharjes.de">Simon Harjes</a> & <a href="http://ppfeufer.de">H.-Peter Pfeufer</a>
 */

/**
 * Changelog:
 * = 1.3.6 (26.01.2011) =
 * Change: moved JavaScript to the footer to improve performance
 *
 * = 1.3.5 (09.01.2011) =
 * Fix: corrected loading of JavaScript after saving action.
 * Update: translation
 * Add: Support for own CSS to style the widget.
 *
 * = 1.3.4 (08. 01. 2011) =
 * Fix: translation in frontend (english/german)
 *
 * = 1.3.3 (08. 01. 2011) =
 * Update: JavaScript
 *
 * = 1.3.2 (11. 12. 2010) =
 * Add: Language Support for english and german
 *
 * = 1.3.1 (05. 12. 2010) =
 * Add: Support via Flattr :-)
 *
 * = 1.3.0 (05. 12. 2010) =
 * Update: Now Using WordPress Widget-API
 * Fix: Major code cleanup
 * Test: Ready for WordPress 3.1 (tested on WordPress 3.1-beta1-16723.)
 *
 * = 1.2.4 =
 * Code cleanup
 *
 * = 1.2.3 =
 * Upload to Wordpress Plugindirectory
 *
 * = 1.2.2 =
 * Fixed a little bug in JavaScript
 *
 * = 1.2.1 =
 * Added lnk to own twitterprofile unter the tweets
 *
 * = 1.2.0 =
 * JavaScript no longer as inline. Now in external file.
 *
 * = 1.1.2 =
 * Little Bugfix in #hashtag function
 *
 * = 1.1.0 =
 * #Hashtags are now linked
 *
 * = 1.0.0 =
 * Initial Release
 */

if(!defined('PPFEUFER_FLATTRSCRIPT')) {
	define('PPFEUFER_FLATTRSCRIPT', 'http://cdn.ppfeufer.de/js/flattr/flattr.js');
}
define('TWEETVIEW_VERSION', '1.3.6');

class Tweetview_Widget extends WP_Widget {
	function Tweetview_Widget() {
		if(function_exists('load_plugin_textdomain')) {
			load_plugin_textdomain('tweetview-sidebar-widget', PLUGINDIR . '/' . dirname(plugin_basename(__FILE__)) . '/l10n', dirname(plugin_basename(__FILE__)) . '/l10n');
		}

		$widget_ops = array(
			'classname' => 'tweetview_widget',
			'description' => __('Tweetview Widget', 'tweetview-sidebar-widget')
		);

		$control_ops = array();

		$this->WP_Widget('tweetview_widget', 'Tweetview Widget', $widget_ops, $control_ops);
	}

	function form($instance) {
		$instance = wp_parse_args((array) $instance, array(
			'tweetview_title' => '',
			'tweetview_username' => '',
			'tweetview_no_tweets' => '5'
		));

		// Version (hidden field)
		echo '<input id="' . $this->get_field_id('plugin-version') . '" name="' . $this->get_field_name('plugin-version') . '" type="hidden" value="' . TWEETVIEW_VERSION . '" />';

		// Titel
		echo '<p style="border-bottom: 1px solid #DFDFDF;"><strong>' . __('Title', 'tweetview-sidebar-widget') . '</strong></p>';
		echo '<p><input id="' . $this->get_field_id('tweetview_title') . '" name="' . $this->get_field_name('tweetview_title') . '" type="text" value="' . $instance['tweetview_title'] . '" /></p>';
		echo '<p style="clear:both;"></p>';

		// Settings
		echo '<p style="border-bottom: 1px solid #DFDFDF;"><strong>' . __('Preferences', 'tweetview-sidebar-widget') . '</strong></p>';
		echo '<p><label>' . __('Username', 'tweetview-sidebar-widget') . '<br /><input id="' . $this->get_field_id('tweetview_username') . '" name="' . $this->get_field_name('tweetview_username') . '" type="text" value="' . $instance['tweetview_username'] . '" /></p>';
		echo '<p><label>' . __('Number of tweets to show', 'tweetview-sidebar-widget') . '<br /></label><input id="' . $this->get_field_id('tweetview_no_tweets') . '" name="' . $this->get_field_name('tweetview_no_tweets') . '" type="text" value="' . $instance['tweetview_no_tweets'] . '" /></p>';
		echo '<p style="clear:both;"></p>';

		// Own CSS
		echo '<p style="border-bottom: 1px solid #DFDFDF;"><strong>' . __('Custom CSS', 'tweetview-sidebar-widget') . '</strong></p>';
		echo '<p><span style="display:inline-block;">' . __('Write your CSS here ...', 'tweetview-sidebar-widget') . ': </span><textarea id="' . $this->get_field_id('own-css') . '" rows="10" name="' . $this->get_field_name('own-css') . '">' . $instance['own-css'] . '</textarea></p>';
		echo '<p style="clear:both;"></p>';

		// Flattr
		echo '<p style="border-bottom: 1px solid #DFDFDF;"><strong>' . __('Like this Plugin? Buy me a coffee.', 'tweetview-sidebar-widget') . '</strong></p>';
		/**
		 * JavaScript für Flattr einfügen
		 */
		if(!defined('PPFEUFER_FLATTRSCRIPT_IS_LOADED')) {
			echo '<script type="text/javascript" src="' . PPFEUFER_FLATTRSCRIPT . '"></script>';
			define('PPFEUFER_FLATTRSCRIPT_IS_LOADED', true);
		}
		echo '<p><a class="FlattrButton" style="display:none;" rev="flattr;button:compact;" href="http://blog.ppfeufer.de/tweetview-widget-anzeige-der-letzten-tweets-in-der-wordpress-sidebar/"></a></p>';
		echo '<p style="clear:both;"></p>';
	}

	function update($new_instance, $old_instance) {
		$instance = $old_instance;

		$new_instance = wp_parse_args((array) $new_instance, array(
			'tweetview_title' => '',
			'tweetview_username' => '',
			'tweetview_no_tweets' => '5'
		));

		$instance['plugin-version'] = strip_tags($new_instance['plugin-version']);
		$instance['tweetview_title'] = strip_tags($new_instance['tweetview_title']);
		$instance['tweetview_username'] = strip_tags($new_instance['tweetview_username']);
		$instance['tweetview_no_tweets'] = strip_tags($new_instance['tweetview_no_tweets']);
		$instance['own-css'] = $new_instance['own-css'];

		print_r($instance);

		return $instance;
	}

	function widget($args, $instance) {
		extract($args);

		echo $before_widget;

		$title = (empty($instance['tweetview_title'])) ? '&nbsp;' : apply_filters('widget_title', $instance['tweetview_title']);

		if(!empty($title)) {
			echo $before_title . $title . $after_title;
		}

		echo $this->tweetview_output($instance, 'widget');
		echo $after_widget;
	}

	function tweetview_output($args = array(), $position) {
		echo '<script type="text/javascript">jQuery(document).ready(function() {twitter.load("' . $args['tweetview_username'] . '", ' . $args['tweetview_no_tweets'] . ')});</script>';
		echo '<ul id="tweetview_tweetlist"><li>' . __('Loading tweets', 'tweetview-sidebar-widget') . ' ...</li></ul>';
		echo '<ul><li>' . __('Follow', 'tweetview-sidebar-widget') . ' <a href="http://twitter.com/' . $args['tweetview_username'] . '">@' . $args['tweetview_username'] . '</a> ' . __('on twitter.', 'tweetview-sidebar-widget') . '</li></ul>';
	}
}

add_action('widgets_init', create_function('', 'return register_widget("Tweetview_Widget");'));

/**
 * Die JavaScripte an den richtigen Stellen laden
 */
if(!is_admin()) {
	/**
	 * jQuery einbinden
	 * Diese werden ab Wordpress-Version 3.0 von Wordpress selbst zur Verfügung gestellt.
	 * Sollte das Plugin "Use Google Libraries" installiert sein, werden die aktuellen Versionen von Google CDN verwendet.
	 */
	wp_enqueue_script('jquery');

	function tweetview_head() {
		/* Header um CSS erweitern, sofern in der Datenbank hinterlegt */
		$array_widgetOptions = get_option('widget_tweetview_widget');
		// CSS suchen
		foreach($array_widgetOptions as $key => $value) {
			if($value['own-css']) {
				$var_sOwnCSS = $value['own-css'];
				break;
			}
		}

		if($var_sOwnCSS != '') {
			// CSS in den Header einfügen
			echo "\n" . '<!-- CSS for Tweetview Widget by H.-Peter Pfeufer [http://ppfeufer.de | http://blog.ppfeufer.de] -->' . "\n" . '<style type="text/css">' . "\n" . $var_sOwnCSS . "\n" . '</style>' . "\n" . '<!-- END of CSS for Tweetview Widget -->' . "\n\n";
		}
	}

	function tweetview_footer() {
		$var_sTwitterScript = '
		<script type="text/javascript">
		J = jQuery.noConflict();
		var twitter = new Object();

		twitter.parseText = function (text) {
			var regexp = /(\b(https?|ftp|file):\/\/[-A-Z0-9+&@#\/%?=~_|!:,.;]*[-A-Z0-9+&@#\/%=~_|])/ig;
			text = text.replace(regexp, \'<a href="$1" target="_blank">$1</a>\');

			var regexp = /\s?(#([A-Z0-9äöü]+))/ig;
			text = text.replace(regexp, \' <a href="http://twitter.com/search?q=%23$2" target="_blank">$1</a>\');

			regexp = /([@])([\w]+)/ig;

			return text.replace(regexp, \'<a href="http://twitter.com/$2" target="_blank">$1$2</a>\');
		}

		twitter.parseSource = function (source) {
			regexp = /rel="nofollow"/ig;
			source = source.replace(regexp, \'\');

			return source;
		}

		String.prototype.delNofollow = function () {
			return this.replace(/ ?rel="nofollow"/ig, \'\');
		}

		twitter.calcTime = function (tstr) {
			var now = new Date();
			var d = tstr.substring(8, 10);
			var m = tstr.substring(4, 7);
			var y = tstr.substring(26, 30);
			var time = tstr.substring(10, 19);
			var date = d + \' \' + m + \' \' + y + \' \' + time + \' +0000\';
			var ts = parseInt(Date.parse(date)) / 1000;
			var diff = Math.round(now.getTime() / 1000 - ts);

			if (diff < 60) {
				var str = diff + ((diff > 1) ? \' ' . __('Seconds', 'tweetview-sidebar-widget') . '\' : \' ' . __('Second', 'tweetview-sidebar-widget') . '\');
			} else if (diff < 3600) {
				var str = Math.round(diff / 60);
				str += ((str > 1) ? \' ' . __('Minutes', 'tweetview-sidebar-widget') . '\' : \' ' . __('Minute', 'tweetview-sidebar-widget') . '\');
			} else if (diff < 86400) {
				var str = Math.round(diff / 3600);
				str += ((str > 1) ? \' ' . __('Hours', 'tweetview-sidebar-widget') . '\' : \' ' . __('Hour', 'tweetview-sidebar-widget') . '\');
			} else {
				var str = Math.round(diff / 86400);
				str += ((str > 1) ? \' ' . __('Days', 'tweetview-sidebar-widget') . '\' : \' ' . __('Day', 'tweetview-sidebar-widget') . '\');
			}

			return str;
		}
		twitter.load = function (name, tweetcount) {
			J.getJSON(\'http://twitter.com/status/user_timeline/\' + name + \'.json?count=\' + tweetcount + \'&callback=?\', function(data) {
				var twitterbox = document.getElementById(\'tweetview_tweetlist\');
				twitterbox.innerHTML = \'\';

				J.each(data, function(i, tweet) {
					if (tweet.created_at != undefined) {
						text = twitter.parseText(tweet.text);
						source = tweet.source.delNofollow();

						var lItem = document.createElement(\'li\');

						lItem.setAttribute(\'class\', \'tweet\');

						twitterbox.appendChild(lItem);
						twitterbox.lastChild.innerHTML = text + \'<br \/>\' + \'' . __('Time ago', 'tweetview-sidebar-widget') . ' <a href="http://twitter.com/\' + name + \'/status/\' + tweet.id + \'" target="_blank">\' + twitter.calcTime(tweet.created_at) + \'</a> via \' + source;
					}
				});
			});
		}
		</script>';

		// JS in den Footer einfügen
		echo "\n" . '<!-- JavaScript for Tweetview Widget by H.-Peter Pfeufer [http://ppfeufer.de | http://blog.ppfeufer.de] and Simon Harjes [http://sharjes.de] -->' . $var_sTwitterScript . "\n" . '<!-- END of JavaScript for Tweetview Widget -->' . "\n\n";
	}

	/**
	 * Header und Footer erweitern
	 */
	add_action('wp_head', 'tweetview_head');
	add_action('wp_footer', 'tweetview_footer');
}
?>